@@ -14,7 +14,7 @@
  * (enclosed in the file GPL).
  *)
 
-(*i $Id: biboutput.ml,v 1.14 2004/03/24 08:10:10 filliatr Exp $ i*)
+(*i $Id: biboutput.ml,v 1.17 2004/10/06 06:20:00 filliatr Exp $ i*)
 
 (*s Output a BibTeX bibliography. *)
 
@@ -69,6 +69,7 @@ let print_crossref html ch = function
   | l -> 
       if not !Options.quiet then
 	eprintf "Warning: cross-references must be constant strings\n";
+      if !Options.warn_error then exit 2;
       print_atom_list html ch l
 
 let print_link_field ch = function
@@ -81,6 +82,7 @@ let print_link_field ch = function
   | l ->
       if not !Options.quiet then
 	eprintf "Warning: web links must be constant strings\n";
+      if !Options.warn_error then exit 2;
       print_atom_list true ch l
 
 let print_command html ch keys = function 
@@ -100,9 +102,9 @@ i*)
       output_string ch "\n"
   | Preamble l ->
       if html then output_string ch "<pre>\n";
-      output_string ch "@PREAMBLE{{";
+      output_string ch "@PREAMBLE{";
       print_atom_list html ch l;
-      output_string ch "}}\n";
+      output_string ch "}\n";
       if html then output_string ch "</pre>\n";
       output_string ch "\n"
   | Abbrev(s,l) ->
@@ -119,6 +121,7 @@ i*)
   | Entry (entry_type,key,fields) ->
       if needs_output key keys then 
 	begin
+	  if html then Html.open_balise ch "p";
 	  if html then begin Html.open_anchor ch key; Html.close_anchor ch end;
 	  if html then output_string ch "<pre>\n";
 	  output_string ch ("@" ^ entry_type ^ "{" ^ key);
@@ -134,6 +137,7 @@ i*)
 	    fields;
 	  output_string ch "\n}\n";
 	  if html then output_string ch "</pre>\n";
+	  if html then Html.close_balise ch "p";
 	  output_string ch "\n"
 
 	end
