@@ -14,7 +14,7 @@
  * (enclosed in the file GPL).
  *)
 
-(*i $Id: biboutput.mli,v 1.3 2001/02/21 09:51:52 filliatr Exp $ i*)
+(*i $Id: biboutput.mli,v 1.4 2003/10/01 15:23:24 filliatr Exp $ i*)
 
 (*s [output_bib html ch bib keys] outputs to the channel [ch] the
    fields of the bibliography [bib] whose key belong to [keys]. [html]
@@ -30,3 +30,8 @@
 open Bibtex
 
 val output_bib : bool -> out_channel -> biblio -> KeySet.t option -> unit
+
+(*s [add_link_field f] declares a new field [f] to be displayed as a web link
+    (when HTML option of [output_bib] is set) *)
+
+val add_link_field : string -> unit
