@@ -14,7 +14,7 @@
  * (enclosed in the file GPL).
  *)
 
-(*i $Id: bibtex.ml,v 1.17 2003/06/19 13:02:02 marche Exp $ i*)
+(*i $Id: bibtex.ml,v 1.21 2004/10/06 08:44:20 marche Exp $ i*)
 
 (*s Datatype for BibTeX bibliographies. *)
 
@@ -48,12 +48,14 @@ let size b = List.length b
 
 let fold = List.fold_right
 
-let rec find_entry key biblio =
-  match biblio with
-    | [] -> raise Not_found
-    | (Entry (_,s,_) as e) :: b ->
-	if s = key then e else find_entry key b
-    | _ :: b -> find_entry key b
+let find_entry key biblio =
+  let rec find key b =
+    match b with
+      | [] -> raise Not_found
+      | (Entry (_,s,_) as e) :: b ->
+	  if String.uppercase s = key then e else find key b
+      | _ :: b -> find key b
+  in find (String.uppercase key) biblio
 
 let add_new_entry command biblio = command :: biblio
 
@@ -100,7 +102,13 @@ let merge_biblios b1 b2 =
     fold
       (fun entry accu -> match entry with
 	 | Entry (_,key,_) -> 
-	     if KeySet.mem key b2keys then accu else entry :: accu
+	     if KeySet.mem key b2keys then 
+	       begin
+		 Format.eprintf "Warning, key '%s' duplicated@." key;
+		 if !Options.warn_error then exit 2;
+		 accu 
+	       end 
+	     else entry :: accu
 	 | _ -> entry :: accu)
       b1
       empty_biblio
@@ -109,7 +117,13 @@ let merge_biblios b1 b2 =
     fold
       (fun entry accu -> match entry with
 	 | Abbrev (key,_) -> 
-	     if KeySet.mem key b1abbrevs then accu else entry :: accu
+	     if KeySet.mem key b1abbrevs then 
+	       begin
+		 Format.eprintf "Warning, key '%s' duplicated@." key;
+		 if !Options.warn_error then exit 2;
+		 accu 
+	       end 
+	     else entry :: accu
 	 | _ -> entry :: accu)
       b2
       new_b1
@@ -191,6 +205,76 @@ let rec expand_abbrevs biblio =
     biblio
     []
 
+let rec expand_crossrefs biblio = 
+  let crossref_table = Hashtbl.create 97 in
+  let add_crossref a l = Hashtbl.add crossref_table (String.uppercase a) l in
+  let find_crossref a = Hashtbl.find crossref_table (String.uppercase a) in
+  let replace_crossref a l = 
+    Hashtbl.replace crossref_table (String.uppercase a) l 
+  in
+  List.iter 
+    (fun command ->
+       match command with
+	 | Entry (t,k,f) ->
+	     begin
+	       try
+		 match List.assoc "CROSSREF" f with
+		   | [String(s)] -> 
+		       add_crossref s []
+		   | _ -> 
+		       begin
+			 Format.eprintf 
+			   "Warning: invalid cross-reference in entry '%s'.@." k;
+			 if !Options.warn_error then exit 2;
+		   end
+	       with Not_found -> ();
+	     end
+	 | _ -> ())
+    biblio;
+  List.iter 
+    (fun command ->
+       match command with
+	 | Entry (t,k,f) ->
+	     begin
+	       try 
+		 let _ = find_crossref k in
+		 if !Options.debug then
+		   Format.eprintf "recording cross-reference '%s'.@." k;
+		 replace_crossref k f
+	       with Not_found -> ()
+	     end
+	 | _ -> ())
+    biblio;
+  fold 
+    (fun command accu ->
+       match command with
+	 | Entry (t,k,f) ->
+	     begin
+	       try
+		 match List.assoc "CROSSREF" f with
+		   | [String(s)] -> 
+		       begin
+			 try 
+			   let f' = find_crossref s in
+			   if f' = [] then
+			     begin
+			       Format.eprintf 
+				 "Warning: cross-reference '%s' not found.@." s;
+			       if !Options.warn_error then exit 2;
+			     end;
+			   Entry (t,k,f@f') :: accu
+			 with Not_found ->
+			   assert false
+		       end
+		   | _ ->  command :: accu
+	       with Not_found -> command :: accu
+	     end
+	 | e ->
+	     e :: accu)
+    biblio
+    []
+
+
 
 let sort comp bib = 
   let comments,preambles,abbrevs,entries =
@@ -212,3 +296,7 @@ let sort comp bib =
        (List.rev_append preambles (List.rev comments)))
 
 
+
+
+let current_key = ref ""
+
