@@ -14,7 +14,7 @@
  * (enclosed in the file GPL).
  *)
 
-(*i $Id: bibtex.mli,v 1.17 2003/06/19 13:02:02 marche Exp $ i*)
+(*i $Id: bibtex.mli,v 1.20 2004/09/17 12:58:33 marche Exp $ i*)
 
 (*s A datatype for BibTeX bibliographies. *)
 
@@ -85,6 +85,8 @@ val find_abbrev : key -> biblio -> command
 
 val expand_abbrevs : biblio -> biblio
 
+val expand_crossrefs : biblio -> biblio
+
 
 (*s sorting bibliography
 
@@ -97,8 +99,17 @@ val expand_abbrevs : biblio -> biblio
   (Entry _, Entry _)
 
   Warning! it is up to you to provide a comparison function that will
-  not place crossrefs after regular entries!
+  not place crossrefs before regular entries!
 
 *)
 
 val sort : (command -> command -> int) -> biblio -> biblio
+
+
+(*
+
+  for parsing
+
+*)
+
+val current_key : string ref
