@@ -14,7 +14,7 @@
  * (enclosed in the file GPL).
  *)
 
-(*i $Id: expand.ml,v 1.10 2002/10/11 16:07:53 filliatr Exp $ i*)
+(*i $Id: expand.ml,v 1.13 2004/08/24 09:27:36 filliatr Exp $ i*)
 
 (*s Expansion of abbreviations in BibTeX databases. *)
 
@@ -32,7 +32,9 @@ let add_abbrev a s = Hashtbl.add abbrev_table a s
 
 let find_abbrev s = Hashtbl.find abbrev_table s
 
-let assoc_months = 
+(* months are predefined abbreviations *)
+let () = 
+  List.iter (fun (id,m) -> add_abbrev id m)
   [ "JAN", "January" ;
     "FEB", "February" ;
     "MAR", "March" ;
@@ -51,18 +53,12 @@ let rec expand_list = function
       ""
   | (Id s) :: rem ->
       (try find_abbrev s with Not_found -> s) ^ (expand_list rem)
-
   | (String s) :: rem ->
       s ^ (expand_list rem)
 
 let rec expand_fields = function
   | [] -> 
       []
-  | ("MONTH" as n,l) :: rem ->
-      let s = expand_list l in
-      	(n,try List.assoc (String.uppercase s) assoc_months 
-	   with Not_found -> s) 
-      	:: (expand_fields rem)
   | (n,l) :: rem -> 
       (n,expand_list l) :: (expand_fields rem)
 
@@ -92,23 +88,31 @@ let rec expand biblio =
 (*s Sort BibTeX entries by decreasing dates. *)
 
 let int_of_month = function
-  | "January" -> 0
-  | "February" -> 1
-  | "March" -> 2
-  | "April" -> 3
-  | "May" -> 4
-  | "June" -> 5
-  | "July" -> 6
-  | "August" -> 7
-  | "September" -> 8
-  | "October" -> 9
-  | "November" -> 10 
-  | "December" -> 11
-  | _ -> 0 (* TODO *)
+  | "Janvier" | "January" -> 0
+  | "Fvrier" | "February" -> 1
+  | "Mars" | "March" -> 2
+  | "Avril" | "April" -> 3
+  | "Mai" | "May" -> 4
+  | "Juin" | "June" -> 5
+  | "Juillet" | "July" -> 6
+  | "Aot" | "August" -> 7
+  | "Septembre" | "September" -> 8
+  | "Octobre" | "October" -> 9
+  | "Novembre" | "November" -> 10 
+  | "Dcembre" | "December" -> 11
+  | _ -> invalid_arg "int_of_month"
 
-type date = { year : int; month : int }
+let month_day_re = Str.regexp "\\([a-zA-Z]+\\)\\( \\|~\\)\\([0-9]+\\)"
 
-let dummy_date = { year = 0; month = 0 }
+let parse_month m =
+  if Str.string_match month_day_re m 0 then
+    int_of_month (Str.matched_group 1 m), int_of_string (Str.matched_group 3 m)
+  else
+    int_of_month m, 1
+
+type date = { year : int; month : int; day : int }
+
+let dummy_date = { year = 0; month = 0; day = 0 }
 
 let extract_year k f =
   try
@@ -116,17 +120,20 @@ let extract_year k f =
   with Failure "int_of_string" ->
     if not !Options.quiet then
       eprintf "Warning: incorrect year in entry %s\n" k;
+    if !Options.warn_error then exit 2;
     0
 
 let extract_month k f =
   try
-    int_of_month (List.assoc "MONTH" f)
+    parse_month (List.assoc "MONTH" f)
   with 
-    | Failure "int_of_string" ->
+    | Not_found ->
+	0,1
+    | _ ->
 	if not !Options.quiet then
 	  eprintf "Warning: incorrect month in entry %s\n" k; 
-	0
-    | Not_found -> 0
+	if !Options.warn_error then exit 2;
+	0,1
 
 let rec find_entry k = function
   | [] -> raise Not_found
@@ -135,8 +142,8 @@ let rec find_entry k = function
 let rec extract_date el (_,k,f) =
   try
     let y = extract_year k f in
-    let m = extract_month k f in
-    { year = y; month = m }
+    let m,d = extract_month k f in
+    { year = y; month = m; day = d }
   with Not_found ->
     try extract_date el (find_entry (List.assoc "CROSSREF" f) el)
     with Not_found -> dummy_date
@@ -144,7 +151,9 @@ let rec extract_date el (_,k,f) =
 let date_order el e1 e2 =
   let d1 = extract_date el e1 in
   let d2 = extract_date el e2 in
-  (d1.year < d2.year) or (d1.year == d2.year & d1.month < d2.month)
+  (d1.year < d2.year) ||
+  (d1.year == d2.year && d1.month < d2.month) ||
+  (d1.year == d2.year && d1.month == d2.month && d1.day < d2.day)
 
 (*s Access to the fields. *)
 
